Crate objc2_browser_engine_core

Crate objc2_browser_engine_core 

Bindings to the BrowserEngineCore framework

See Apple’s docs and the general docs on framework crates for more information.

Structs

BEAudioSessionBEAudioSession and objc2
An object that represents an audio session

Functions

be_keventBEkevent and libc
Safety
be_kevent64BEkevent and libc
Safety
be_memory_inline_jit_restrict_rwx_to_rw_with_witnessAArch64 and BEMemory
These functions that can toggle JIT R^X permissions, while enforcing control flow integrity using PAC. This function is intended to be used only in performance-critical sections of code. Please consult the documentation extensively before relying on this API.
be_memory_inline_jit_restrict_rwx_to_rx_with_witnessAArch64 and BEMemory
See be_memory_inline_jit_restrict_rwx_to_rw_with_witness.
be_memory_inline_jit_restrict_with_witness_supportedAArch64 and BEMemory
Returns true iff the inlinable version of the jit_write_protect API is available.